#Script to analyze the F2b data 

#Define wd
setwd("YOUR DIR - SET AS SAME LEVEL AS INPUT")

#Define parameters
threshold = 100000

#Define helper functions
#1) Loader function

f_file_loader_a <- function(fileloc, arg, col_upper = 5, col_lower = 2){
  row2 = read_tsv(fileloc, skip = 9) %>% filter(Row == 2 & Column <= col_upper & Column >= col_lower) %>%
    mutate(condition = str_replace_all(Column ,c("2" = "F", "3" = "B", "4" = "C", "5" = "FB")),
           rep = as.character(arg)) %>%
    select(condition,
           rep, 
           organoid = "Object No",
           Volume = "Touching Objects Removed - Volume Organoids Volume [m]",
           SArea = "Touching Objects Removed - Volume Organoids Surface Area [m]",
           InnerSphere = "Touching Objects Removed - Volume Organoids Inner Sphere Radius [m]") %>%
    filter(Volume >= threshold)
  
  row3 = read_tsv(fileloc, skip = 9) %>% filter(Row == 3 & Column <= col_upper & Column >= col_lower) %>%
    mutate(condition = str_replace_all(Column ,c("2" = "CB", "3" = "All", "4" = "PegO", "5" = "CF")),
           rep = as.character(arg)) %>%
    select(condition,
           rep, 
           organoid = "Object No",
           Volume = "Touching Objects Removed - Volume Organoids Volume [m]",
           SArea = "Touching Objects Removed - Volume Organoids Surface Area [m]",
           InnerSphere = "Touching Objects Removed - Volume Organoids Inner Sphere Radius [m]") %>%
    filter(Volume >= threshold)
  res = rbind(row2, row3)
  return(res)
}

f_file_loader_ef <- function(fileloc, arg, col_upper = 5, col_lower = 2){
  row2 = read_tsv(fileloc, skip = 9) %>% filter(Row == 2 & Column <= col_upper & Column >= col_lower) %>%
    mutate(condition = str_replace_all(Column ,c("2" = "F", "3" = "B", "4" = "C", "5" = "FB")),
           rep = as.character(arg)) %>%
    select(condition,
           rep, 
           organoid = "Object No",
           Volume = "Touching Objects Removed - Volume Organoids Volume [m]",
           SArea = "Touching Objects Removed - Volume Organoids Surface Area [m]",
           InnerSphere = "Touching Objects Removed - Volume Organoids Inner Sphere Radius [m]") %>%
    filter(Volume >= threshold)
  
  row3 = read_tsv(fileloc, skip = 9) %>% filter(Row == 3 & Column <= col_upper & Column >= col_lower) %>%
    mutate(condition = str_replace_all(Column ,c("2" = "CF", "3" = "CB", "4" = "All", "5" = "PegO")),
           rep = as.character(arg)) %>%
    select(condition,
           rep, 
           organoid = "Object No",
           Volume = "Touching Objects Removed - Volume Organoids Volume [m]",
           SArea = "Touching Objects Removed - Volume Organoids Surface Area [m]",
           InnerSphere = "Touching Objects Removed - Volume Organoids Inner Sphere Radius [m]") %>%
    filter(Volume >= threshold)
  res = rbind(row2, row3)
  return(res)
}

#Load files in 
full_res_28a <- f_file_loader_a(fileloc = "./E28a_Results.txt", 
                               arg = "R1") %>%  
  mutate(condition = str_replace_all(condition ,c("All" = "CBF_1.0", "PegO"= "CBF_0.5")))

full_res_28e <- f_file_loader_ef(fileloc = "./E28e_Results.txt", 
                                arg = "R2") %>%  
  mutate(condition = str_replace_all(condition ,c("All" = "CBF_1.0", "PegO"= "CBF_0.5")))

full_res_28f <- f_file_loader_ef(fileloc = "./E28f_Results.txt", 
                                arg = "R3") %>%  
  mutate(condition = str_replace_all(condition ,c("All" = "CBF_1.0", "PegO"= "CBF_0.5")))

#Generate full results 
full_res <- rbind(full_res_28a, 
                  full_res_28e,
                  full_res_28f)

#Calculate statiscis for individual replicates (F against all)
e28a_stats <- compare_means(Volume ~ condition, full_res_28a, method = "wilcox.test", ref.group = "F", p.adjust.method = "BH")
e28e_stats <- compare_means(Volume ~ condition, full_res_28e, method = "wilcox.test", ref.group = "F", p.adjust.method = "BH")
e28f_stats <- compare_means(Volume ~ condition, full_res_28f, method = "wilcox.test", ref.group = "F", p.adjust.method = "BH")


#Statistics across everything
full_stats_F <- compare_means(Volume ~ condition, full_res, method = "wilcox.test", ref.group = "F", p.adjust.method = "BH")
full_stats_C <- compare_means(Volume ~ condition, full_res, method = "wilcox.test", ref.group = "C", p.adjust.method = "BH")

#Save all stats 
write_csv(e28a_stats, "./output/F2b_28a_F_stats.csv")
write_csv(e28e_stats, "./output/F2b_28e_F_stats.csv")
write_csv(e28f_stats, "./output/F2b_28f_F_stats.csv")
write_csv(full_stats_F, "./output/F2b_full_F_stats.csv")
write_csv(full_stats_C, "./output/F2b_full_C_stats.csv")

#Export the actual data 
write_csv(full_res, "./output/F2b_Full_results_stacked.csv")
write_csv(full_res_28a, "./output/F2b_Full_results_28a.csv")
write_csv(full_res_28e, "./output/F2b_Full_results_28e.csv")
write_csv(full_res_28f, "./output/F2b_Full_results_28f.csv")
